PCB Environment: Data Fields - Functions

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all functions with links to the structures/unions they belong to:

### - u -

- U() : GridDirection
- UIActions() : UIActions
- UL() : GridDirection
- undoAs() : Action
- UniformGrid25() : UniformGrid25
- unitsToMicrometers() : PCBoard
- unitsToNanometers() : PCBoard
- unitToExp10() : DSNParserBase
- unquote() : DSNParserBase
- unquotePin() : DSNParserBase
- unrasterizeTracks() : PCBoard
- unrouteConnection() : UIActions
- unrouteSegment() : UIActions
- unrouteSelection() : UIActions
- unsignedArea() : AShape, CircleEx, IsoRectEx, PolygonEx, TriangleEx, WideSegment_25
- update() : NavMesh, PCBoardMesh, RatsNest, RoutePainter, RoutePainterLines, TriList, ui::NavGrid, ViaPainter
- updateForRemovedLayers() : Connection, Track
- updateHL() : RatsNest
- updateIndicators() : UIActions
- updateOwner() : LogFile
- updateView() : StateRepresentation
- UR() : GridDirection
- usecsSinceStart() : Agent
- UserAgent() : UserAgent